@@ -1,5 +1,5 @@
 """Shows how to use relative sorting in test classes, see
-See https://pytest-dev.github.io/pytest-order/dev/#referencing-of-tests-in-other-classes-or-modules  # noqa: E501
+See https://pytest-order.readthedocs.io/en/stable/#referencing-of-tests-in-other-classes-or-modules  # noqa: E501
 """
 import pytest
 
