@@ -1,5 +1,5 @@
 """One of the example files showing relative ordering between modules.
-See https://pytest-dev.github.io/pytest-order/dev/#referencing-of-tests-in-other-classes-or-modules  # noqa: E501
+See https://pytest-order.readthedocs.io/en/stable/#referencing-of-tests-in-other-classes-or-modules  # noqa: E501
 """
 
 
