@@ -1,5 +1,5 @@
 """Test with ordering (as opposed to test.py) from the quick start chapter.
-See https://pytest-dev.github.io/pytest-order/dev/#quickstart
+See https://pytest-order.readthedocs.io/en/stable/#quickstart
 """
 import pytest
 
