@@ -1,5 +1,5 @@
 """Test showing the behavior of the --order-dependencies option.
-See https://pytest-dev.github.io/pytest-order/dev/#order-dependencies
+See https://pytest-order.readthedocs.io/en/stable/#order-dependencies
 """
 import pytest
 
