@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
 from typing import List
 
 import pytest
 from _pytest.config import Config
 from _pytest.config.argparsing import Parser
 from _pytest.main import Session
+from _pytest.mark import Mark
 from _pytest.python import Function
 
 from .sorter import Sorter
@@ -17,8 +17,7 @@ def pytest_configure(config: Config) -> None:
     """
 
     provided_by_pytest_order = (
-        "Provided by pytest-order. "
-        "See also: https://pytest-dev.github.io/pytest-order/"
+        "Provided by pytest-order. " "See also: https://pytest-order.readthedocs.io/"
     )
 
     config_line = (
@@ -34,8 +33,8 @@ def pytest_configure(config: Config) -> None:
         wrapper = pytest.hookimpl(tryfirst=True)
     else:
         wrapper = pytest.hookimpl(trylast=True)
-    setattr(
-        OrderingPlugin, "pytest_collection_modifyitems", wrapper(modify_items)
+    OrderingPlugin.pytest_collection_modifyitems = wrapper(  # type:ignore[attr-defined]
+        modify_items
     )
     config.pluginmanager.register(OrderingPlugin(), "orderingplugin")
 
@@ -102,6 +101,49 @@ def pytest_addoption(parser: Parser) -> None:
             "if needed."
         ),
     )
+    group.addoption(
+        "--order-marker-prefix",
+        action="store",
+        dest="order_marker_prefix",
+        help=(
+            "If set, markers starting with the given prefix followed by a number "
+            "are handled like order markers with an index."
+        ),
+    )
+
+
+def _get_mark_description(mark: Mark):
+    if mark.kwargs:
+        return ", ".join([f"{k}={v}" for k, v in mark.kwargs.items()])
+    elif mark.args:
+        return f"index={mark.args[0]}"
+    return mark
+
+
+def pytest_generate_tests(metafunc):
+    """
+    Handle multiple pytest.mark.order decorators.
+
+    Make parametrized tests with corresponding order marks.
+    """
+    if getattr(metafunc, "function", False):
+        if getattr(metafunc.function, "pytestmark", False):
+            # Get list of order marks
+            marks = metafunc.function.pytestmark
+            order_marks = [mark for mark in marks if mark.name == "order"]
+            if len(order_marks) > 1:
+                # Remove all order marks
+                metafunc.function.pytestmark = [
+                    mark for mark in marks if mark.name != "order"
+                ]
+                # Prepare arguments for parametrization with order marks
+                args = [
+                    pytest.param(_get_mark_description(mark), marks=[mark])
+                    for mark in order_marks
+                ]
+                if "order" not in metafunc.fixturenames:
+                    metafunc.fixturenames.append("order")
+                metafunc.parametrize("order", args)
 
 
 class OrderingPlugin:
@@ -113,8 +155,6 @@ class OrderingPlugin:
     """
 
 
-def modify_items(
-    session: Session, config: Config, items: List[Function]
-) -> None:
+def modify_items(session: Session, config: Config, items: List[Function]) -> None:
     sorter = Sorter(config, items)
     items[:] = sorter.sort_items()
