@@ -25,9 +25,7 @@ def item_names_for(testdir):
 
 @pytest.fixture
 def test_path(testdir):
-    testdir.tmpdir.join("pytest.ini").write(
-        "[pytest]\nconsole_output_style = classic"
-    )
+    testdir.tmpdir.join("pytest.ini").write("[pytest]\nconsole_output_style = classic")
     yield testdir
 
 
@@ -39,6 +37,7 @@ def ignore_settings(mocker):
     settings.return_value.scope = Scope.SESSION
     settings.return_value.group_scope = Scope.SESSION
     settings.return_value.scope_level = 0
+    settings.return_value.marker_prefix = None
     yield settings
 
 
