@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-
 import pytest
 
 
 def test_ignore_order_with_dependency(item_names_for):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         @pytest.mark.dependency()
@@ -17,13 +14,11 @@ def test_ignore_order_with_dependency(item_names_for):
         def test_b():
             pass
         """
-    )
     assert item_names_for(tests_content) == ["test_a", "test_b"]
 
 
 def test_order_with_dependency(item_names_for):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         @pytest.mark.dependency(depends=["test_b"])
@@ -35,7 +30,6 @@ def test_order_with_dependency(item_names_for):
         def test_b():
             pass
         """
-    )
     assert item_names_for(tests_content) == ["test_b", "test_a"]
 
 
@@ -117,17 +111,13 @@ def multiple_dependencies_test():
 def test_order_multiple_dependencies_default(
     multiple_dependencies_test, item_names_for
 ):
-    assert item_names_for(multiple_dependencies_test) == [
-        "test_a", "test_b", "test_c"
-    ]
+    assert item_names_for(multiple_dependencies_test) == ["test_a", "test_b", "test_c"]
 
 
 def test_order_multiple_dependencies_ordered(
     multiple_dependencies_test, item_names_for, order_dependencies
 ):
-    assert item_names_for(multiple_dependencies_test) == [
-        "test_b", "test_c", "test_a"
-    ]
+    assert item_names_for(multiple_dependencies_test) == ["test_b", "test_c", "test_a"]
 
 
 @pytest.fixture
@@ -165,11 +155,13 @@ def test_order_dependencies_no_auto_mark(no_dep_marks):
     )
     result = no_dep_marks.runpytest("-v", "--order-dependencies")
     result.assert_outcomes(passed=2, skipped=1)
-    result.stdout.fnmatch_lines([
-        "test_auto.py::test_a SKIPPED*",
-        "test_auto.py::test_b PASSED",
-        "test_auto.py::test_c PASSED",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "test_auto.py::test_a SKIPPED*",
+            "test_auto.py::test_b PASSED",
+            "test_auto.py::test_c PASSED",
+        ]
+    )
 
 
 def test_order_dependencies_auto_mark(no_dep_marks):
@@ -185,11 +177,13 @@ def test_order_dependencies_auto_mark(no_dep_marks):
     )
     result = no_dep_marks.runpytest("-v", "--order-dependencies")
     result.assert_outcomes(passed=3, failed=0)
-    result.stdout.fnmatch_lines([
-        "test_auto.py::test_b PASSED",
-        "test_auto.py::test_c PASSED",
-        "test_auto.py::test_a PASSED",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "test_auto.py::test_b PASSED",
+            "test_auto.py::test_c PASSED",
+            "test_auto.py::test_a PASSED",
+        ]
+    )
 
 
 @pytest.fixture(scope="module")
@@ -213,22 +207,17 @@ def named_dependency_test():
 
 
 def test_order_named_dependency_default(named_dependency_test, item_names_for):
-    assert item_names_for(named_dependency_test) == [
-        "test_a", "test_b", "test_c"
-    ]
+    assert item_names_for(named_dependency_test) == ["test_a", "test_b", "test_c"]
 
 
 def test_order_named_dependency_ordered(
     named_dependency_test, item_names_for, order_dependencies
 ):
-    assert item_names_for(named_dependency_test) == [
-        "test_b", "test_a", "test_c"
-    ]
+    assert item_names_for(named_dependency_test) == ["test_b", "test_a", "test_c"]
 
 
 def test_dependency_in_class(item_names_for, order_dependencies):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         class Test:
@@ -244,17 +233,15 @@ def test_dependency_in_class(item_names_for, order_dependencies):
             def test_c(self):
                 assert True
         """
-    )
     assert item_names_for(tests_content) == [
-        "Test::test_c", "Test::test_a", "Test::test_b"
+        "Test::test_c",
+        "Test::test_a",
+        "Test::test_b",
     ]
 
 
-def test_unresolved_dependency_in_class(
-    item_names_for, order_dependencies, capsys
-):
-    tests_content = (
-        """
+def test_unresolved_dependency_in_class(item_names_for, order_dependencies, capsys):
+    tests_content = """
         import pytest
 
         class Test:
@@ -270,9 +257,10 @@ def test_unresolved_dependency_in_class(
             def test_c(self):
                 assert True
         """
-    )
     assert item_names_for(tests_content) == [
-        "Test::test_a", "Test::test_b", "Test::test_c"
+        "Test::test_a",
+        "Test::test_b",
+        "Test::test_c",
     ]
     out, err = capsys.readouterr()
     warning = "Cannot resolve the dependency marker 'test_c' - ignoring it"
@@ -280,8 +268,7 @@ def test_unresolved_dependency_in_class(
 
 
 def test_named_dependency_in_class(item_names_for, order_dependencies):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         class Test:
@@ -297,15 +284,15 @@ def test_named_dependency_in_class(item_names_for, order_dependencies):
             def test_c(self):
                 assert True
         """
-    )
     assert item_names_for(tests_content) == [
-        "Test::test_c", "Test::test_a", "Test::test_b"
+        "Test::test_c",
+        "Test::test_a",
+        "Test::test_b",
     ]
 
 
 def test_dependencies_in_classes(item_names_for, order_dependencies):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         class TestA:
@@ -332,7 +319,6 @@ def test_dependencies_in_classes(item_names_for, order_dependencies):
             def test_c(self):
                 assert True
         """
-    )
     assert item_names_for(tests_content) == [
         "TestA::test_c",
         "TestB::test_a",
@@ -344,8 +330,7 @@ def test_dependencies_in_classes(item_names_for, order_dependencies):
 
 
 def test_class_scope_dependencies(item_names_for, order_dependencies):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         class TestA:
@@ -360,9 +345,10 @@ def test_class_scope_dependencies(item_names_for, order_dependencies):
             def test_c(self):
                 assert True
         """
-    )
     assert item_names_for(tests_content) == [
-        "TestA::test_b", "TestA::test_c", "TestA::test_a"
+        "TestA::test_b",
+        "TestA::test_c",
+        "TestA::test_a",
     ]
 
 
@@ -403,12 +389,14 @@ def test_named_dependency_in_modules(test_path):
 
     result = test_path.runpytest("-v", "--order-dependencies")
     result.assert_outcomes(passed=4, failed=0)
-    result.stdout.fnmatch_lines([
-        "test_ndep1.py::Test1::test_one PASSED",
-        "test_ndep2.py::test_one PASSED",
-        "test_ndep1.py::Test1::test_two PASSED",
-        "test_ndep2.py::test_two PASSED",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "test_ndep1.py::Test1::test_one PASSED",
+            "test_ndep2.py::test_one PASSED",
+            "test_ndep1.py::Test1::test_two PASSED",
+            "test_ndep2.py::test_two PASSED",
+        ]
+    )
 
 
 @pytest.mark.skipif(
@@ -449,12 +437,14 @@ def test_dependency_in_modules(test_path):
 
     result = test_path.runpytest("-v", "--order-dependencies")
     result.assert_outcomes(passed=4, failed=0)
-    result.stdout.fnmatch_lines([
-        "test_unnamed_dep1.py::Test1::test_one PASSED",
-        "test_unnamed_dep2.py::test_one PASSED",
-        "test_unnamed_dep1.py::Test1::test_two PASSED",
-        "test_unnamed_dep2.py::test_two PASSED",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "test_unnamed_dep1.py::Test1::test_one PASSED",
+            "test_unnamed_dep2.py::test_one PASSED",
+            "test_unnamed_dep1.py::Test1::test_two PASSED",
+            "test_unnamed_dep2.py::test_two PASSED",
+        ]
+    )
 
 
 def test_same_dependency_in_modules(test_path):
@@ -490,17 +480,18 @@ def test_same_dependency_in_modules(test_path):
     )
     result = test_path.runpytest("-v", "--order-dependencies")
     result.assert_outcomes(passed=4, failed=0)
-    result.stdout.fnmatch_lines([
-        "test_module_dep1.py::test_two PASSED",
-        "test_module_dep1.py::test_one PASSED",
-        "test_module_dep2.py::test_two PASSED",
-        "test_module_dep2.py::test_one PASSED",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "test_module_dep1.py::test_two PASSED",
+            "test_module_dep1.py::test_one PASSED",
+            "test_module_dep2.py::test_two PASSED",
+            "test_module_dep2.py::test_one PASSED",
+        ]
+    )
 
 
 def test_unknown_dependency(item_names_for, order_dependencies, capsys):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         class Test:
@@ -514,9 +505,10 @@ def test_unknown_dependency(item_names_for, order_dependencies, capsys):
             def test_c(self):
                 assert True
         """
-    )
     assert item_names_for(tests_content) == [
-        "Test::test_a", "Test::test_b", "Test::test_c"
+        "Test::test_a",
+        "Test::test_b",
+        "Test::test_c",
     ]
     out, err = capsys.readouterr()
     warning = "Cannot resolve the dependency marker 'test_3' - ignoring it."
@@ -524,8 +516,7 @@ def test_unknown_dependency(item_names_for, order_dependencies, capsys):
 
 
 def test_unsupported_order_with_dependency(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.dependency(depends=["test_2"])
@@ -536,6 +527,5 @@ def test_unsupported_order_with_dependency(item_names_for):
         def test_2():
             pass
         """
-    )
     with pytest.warns(UserWarning, match="Unknown order attribute:'unknown'"):
         assert item_names_for(test_content) == ["test_1", "test_2"]
