@@ -1,12 +1,10 @@
-# -*- coding: utf-8 -*-
 from textwrap import dedent
 
 import pytest
 
 
 def test_relative(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after="test_second")
@@ -20,15 +18,11 @@ def test_relative(item_names_for):
         def test_first():
             pass
         """
-    )
-    assert item_names_for(test_content) == [
-        "test_first", "test_second", "test_third"
-    ]
+    assert item_names_for(test_content) == ["test_first", "test_second", "test_third"]
 
 
 def test_relative2(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after="test_second")
@@ -49,15 +43,17 @@ def test_relative2(item_names_for):
         def test_four():
             pass
         """
-    )
     assert item_names_for(test_content) == [
-        "test_first", "test_second", "test_third", "test_four", "test_five"
+        "test_first",
+        "test_second",
+        "test_third",
+        "test_four",
+        "test_five",
     ]
 
 
 def test_relative3(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after="test_second")
@@ -78,15 +74,17 @@ def test_relative3(item_names_for):
         def test_four():
             pass
         """
-    )
     assert item_names_for(test_content) == [
-        "test_first", "test_second", "test_third", "test_four", "test_five"
+        "test_first",
+        "test_second",
+        "test_third",
+        "test_four",
+        "test_five",
     ]
 
 
 def test_relative_in_class(item_names_for):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         class Test:
@@ -100,15 +98,15 @@ def test_relative_in_class(item_names_for):
             def test_c(self):
                 pass
         """
-    )
     assert item_names_for(tests_content) == [
-        "Test::test_b", "Test::test_a", "Test::test_c"
+        "Test::test_b",
+        "Test::test_a",
+        "Test::test_c",
     ]
 
 
 def test_relative_in_classes(item_names_for):
-    tests_content = (
-        """
+    tests_content = """
         import pytest
 
         class TestA:
@@ -134,7 +132,6 @@ def test_relative_in_classes(item_names_for):
             def test_c(self):
                 pass
         """
-    )
     assert item_names_for(tests_content) == [
         "TestB::test_a",
         "TestA::test_c",
@@ -184,8 +181,9 @@ def fixture_path(test_path):
     )
     test_path.mkpydir("sub")
     path = test_path.tmpdir.join("sub", "mod3_test.py")
-    path.write(dedent(
-        """
+    path.write(
+        dedent(
+            """
         import pytest
 
         @pytest.mark.order(before="mod2_test.py::TestB::test_c")
@@ -198,29 +196,31 @@ def fixture_path(test_path):
         def test_c():
             pass
         """
-    ))
+        )
+    )
     yield test_path
 
 
 def test_relative_in_modules(fixture_path):
     result = fixture_path.runpytest("-v")
     result.assert_outcomes(passed=9, failed=0)
-    result.stdout.fnmatch_lines([
-        "mod2_test.py::TestB::test_a PASSED",
-        "mod1_test.py::TestA::test_c PASSED",
-        "mod2_test.py::TestB::test_b PASSED",
-        "mod1_test.py::TestA::test_a PASSED",
-        "sub/mod3_test.py::test_a PASSED",
-        "mod2_test.py::TestB::test_c PASSED",
-        "sub/mod3_test.py::test_b PASSED",
-        "mod1_test.py::TestA::test_b PASSED",
-        "sub/mod3_test.py::test_c PASSED",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "mod2_test.py::TestB::test_a PASSED",
+            "mod1_test.py::TestA::test_c PASSED",
+            "mod2_test.py::TestB::test_b PASSED",
+            "mod1_test.py::TestA::test_a PASSED",
+            "sub/mod3_test.py::test_a PASSED",
+            "mod2_test.py::TestB::test_c PASSED",
+            "sub/mod3_test.py::test_b PASSED",
+            "mod1_test.py::TestA::test_b PASSED",
+            "sub/mod3_test.py::test_c PASSED",
+        ]
+    )
 
 
 def test_false_insert(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after="test_a")
@@ -234,15 +234,11 @@ def test_false_insert(item_names_for):
         def test_first():
             pass
         """
-    )
-    assert item_names_for(test_content) == [
-        "test_third", "test_second", "test_first"
-    ]
+    assert item_names_for(test_content) == ["test_third", "test_second", "test_first"]
 
 
 def test_mixed_markers1(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(2)
@@ -257,13 +253,11 @@ def test_mixed_markers1(item_names_for):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_3", "test_1", "test_2"]
 
 
 def test_mixed_markers2(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(2)
@@ -278,13 +272,11 @@ def test_mixed_markers2(item_names_for):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_3", "test_2", "test_1"]
 
 
 def test_combined_markers1(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(2)
@@ -298,13 +290,11 @@ def test_combined_markers1(item_names_for):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_3", "test_1", "test_2"]
 
 
 def test_combined_markers2(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         def test_1():
@@ -318,13 +308,11 @@ def test_combined_markers2(item_names_for):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_3", "test_2", "test_1"]
 
 
 def test_combined_markers3(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         def test_1():
@@ -338,13 +326,11 @@ def test_combined_markers3(item_names_for):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_2", "test_3", "test_1"]
 
 
 def test_mixed_markers4(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(2)
@@ -358,13 +344,11 @@ def test_mixed_markers4(item_names_for):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_3", "test_2", "test_1"]
 
 
 def test_multiple_markers_in_same_test(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after=["test_3", "test_4", "test_5"])
@@ -384,15 +368,17 @@ def test_multiple_markers_in_same_test(item_names_for):
         def test_5():
             pass
         """
-    )
     assert item_names_for(test_content) == [
-        "test_4", "test_2", "test_3", "test_5", "test_1"
+        "test_4",
+        "test_2",
+        "test_3",
+        "test_5",
+        "test_1",
     ]
 
 
 def test_dependency_after_unknown_test(item_names_for, capsys):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after="some_module.py::test_2")
@@ -402,7 +388,6 @@ def test_dependency_after_unknown_test(item_names_for, capsys):
         def test_2():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_1", "test_2"]
     out, err = capsys.readouterr()
     warning = (
@@ -413,8 +398,7 @@ def test_dependency_after_unknown_test(item_names_for, capsys):
 
 
 def test_dependency_before_unknown_test(item_names_for, capsys):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         def test_1():
@@ -427,19 +411,16 @@ def test_dependency_before_unknown_test(item_names_for, capsys):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_1", "test_2", "test_3"]
     out, err = capsys.readouterr()
     warning = (
-        "cannot execute 'test_2' relative to others: 'test_4' "
-        "- ignoring the marker"
+        "cannot execute 'test_2' relative to others: 'test_4' " "- ignoring the marker"
     )
     assert warning in out
 
 
 def test_dependency_in_class_before_unknown_test(item_names_for, capsys):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         class Test:
@@ -453,21 +434,20 @@ def test_dependency_in_class_before_unknown_test(item_names_for, capsys):
             def test_3(self):
                 pass
         """
-    )
     assert item_names_for(test_content) == [
-        "Test::test_1", "Test::test_2", "Test::test_3"
+        "Test::test_1",
+        "Test::test_2",
+        "Test::test_3",
     ]
     out, err = capsys.readouterr()
     warning = (
-        "cannot execute 'test_2' relative to others: 'test_4' "
-        "- ignoring the marker"
+        "cannot execute 'test_2' relative to others: 'test_4' " "- ignoring the marker"
     )
     assert warning in out
 
 
 def test_dependency_loop(item_names_for, capsys):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after="test_3")
@@ -482,19 +462,16 @@ def test_dependency_loop(item_names_for, capsys):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == ["test_2", "test_1", "test_3"]
     out, err = capsys.readouterr()
     warning = (
-        "cannot execute test relative to others: "
-        "test_dependency_loop.py::test_3"
+        "cannot execute test relative to others: " "test_dependency_loop.py::test_3"
     )
     assert warning in out
 
 
 def test_dependency_on_parametrized_test(item_names_for):
-    test_content = (
-        """
+    test_content = """
         import pytest
 
         @pytest.mark.order(after="test_2")
@@ -509,8 +486,11 @@ def test_dependency_on_parametrized_test(item_names_for):
         def test_3():
             pass
         """
-    )
     assert item_names_for(test_content) == [
-        "test_3", "test_2[aaaaa]", "test_2[bbbbb]",
-        "test_2[ccccc]", "test_2[ddddd]", "test_1"
+        "test_3",
+        "test_2[aaaaa]",
+        "test_2[bbbbb]",
+        "test_2[ccccc]",
+        "test_2[ddddd]",
+        "test_1",
     ]
